// app.js
import dotenv from "dotenv";
dotenv.config(); // Load from default .env file

import express from "express";
import { authenticate } from "./models/odooService.js";

import attendanceRoutes from "./routes/attendanceRoutes.js";
import employeeRoutes from "./routes/employeeRoutes.js";

const app = express();
app.use(express.json());

app.use("/api/employees", employeeRoutes);
app.use("/api/attendances", attendanceRoutes);

const PORT = process.env.PORT || 3000;

app.listen(PORT, async () => {
    console.log(`✅ Server running on http://localhost:${PORT}`);

    try {
        const uid = await authenticate();
        if (uid) {
            console.log(`🟢 Connected to Odoo! UID: ${uid}`);
        } else {
            console.log(`🔴 Odoo connection failed: Invalid credentials.`);
        }
    } catch (err) {
        console.error(`❌ Error connecting to Odoo:`, err.message);
    }
});
