// controllers/employeeController.js
import { fetchEmployees, fetchEmployeeById } from "../models/odoo/employee.js";

export const getEmployees = async (req, res) => {
    try {
        const employees = await fetchEmployees();

        if (!employees || employees.length === 0) {
            return res
                .status(404)
                .json({ message: "No employee records found" });
        }

        res.json(employees);
    } catch (err) {
        console.error(err);
        res.status(500).json({ error: "Failed to fetch employees" });
    }
};

export const getEmployeeById = async (req, res) => {
    const { employee_id } = req.params;
    try {
        const employee = await fetchEmployeeById(parseInt(employee_id));
        if (!employee) {
            return res.status(404).json({ error: "Employee not found" });
        }
        res.json(employee);
    } catch (err) {
        console.error(err);
        res.status(500).json({ error: "Failed to fetch employee" });
    }
};
